from os.path import splitext

from mutagen.flac import FLAC
from mutagen.oggvorbis import OggVorbis
from mutagen.mp3 import MP3
from mutagen.asf import ASF
from mutagen.mp4 import MP4

from .enums import Mappings, Extensions


def _try(klass, audiofile):
    try:
        return klass(audiofile)
    except:
        pass
    return None

def get_metadata(audiofile):
    ext = splitext(audiofile)[-1].lower()
    if ext == Extensions.MP3:
        return _try(MP3, audiofile), Mappings.ID3
    elif ext == Extensions.FLAC:
        return _try(FLAC, audiofile), Mappings.GENERIC
    elif ext == Extensions.OGG:
        return _try(OggVorbis, audiofile), Mappings.GENERIC
    elif ext == Extensions.ASF or ext == Extensions.WMA:
        return _try(ASF, audiofile), Mappings.ASF
    elif ext == Extensions.M4A or ext == Extensions.M4A or ext == Extensions.AAC:
        return _try(MP4, audiofile), Mappings.MP4
    elif ext == Extensions.WAV:
        return None, Mappings.GENERIC
    return None, Mappings.GENERIC


class ICollector(object):

    def __init__(self, collection):
        self.collection = collection
        return

    def send_message(self, msg={}):
        self.collection.manager.on_collector_message(
            self, msg)
        return

    def send_finished_message(self, msg={}):
        self.progress = -1
        self.collection.manager.on_collector_finished(
            self, msg)
        return

    @staticmethod
    def index_document(*args, **kwargs):
        raise NotImplementedError("Collector needs to implement staticmethod %s" % ICollector.index_document)

    def index_all(self, *args, **kwargs):
        raise NotImplementedError("Collector needs to implement %s" % self.index_all)

    def setup(self):
        raise NotImplementedError("Collector needs to implement %s" % self.setup)

    def run(self):
        raise NotImplementedError("Collector needs to implement %s" % self.run)

    def teardown(self):
        raise NotImplementedError("Collector needs to implement %s" % self.teardown)

    def read_metadata(self):
        # should return xapian.Database instance
        raise NotImplementedError("Collector needs to implement %s" % self.read_metadata)

    def save_metadata(self, db):
        raise NotImplementedError("Collector needs to implement %s" % self.save_metadata)
