from PyQt4.QtCore import (
    QAbstractListModel, QModelIndex, pyqtProperty, pyqtSignal)


class _Facet(object):

    """ Fake facet object """

    def __init__(self, term, termfreq):
        self.term = term
        self.termfreq = termfreq
        return


class ArtistsModel(QAbstractListModel):

    ROLE_ARTIST_NAME = "_artist"
    ROLE_TERM_FREQ = "_termfreq"

    COLUMNS = (ROLE_ARTIST_NAME, ROLE_TERM_FREQ)
    ROLES = dict(enumerate(COLUMNS))

    _silentSignal = pyqtSignal()
    allCountChanged = pyqtSignal()

    def __init__(self):
        QAbstractListModel.__init__(self)
        self.setRoleNames(ArtistsModel.ROLES)
        self._count = 0
        self._values = []
        self._tot = 0
        return

    def clear(self):
        self.beginResetModel()
        self._count = 0
        self._values = []
        self.endResetModel()
        return

    def set_spy(self, spy):
        self.clear()

        vals = []
        tot = 0
        for facet in list(spy.values()):
            vals.append(facet)
            tot += facet.termfreq

        L = len(vals)
        if L > 1:
            L += 1
            vals.insert(0, _Facet("<b>All Artists</b>", tot))
        self._tot = tot

        self._count = L
        self.beginInsertRows(QModelIndex(), 0, self._count-1)
        self._values = vals
        self.endInsertRows()

        self.allCountChanged.emit()
        return

    def get_artist_index(self, artist_name):
        if not self._values:
            return 0
        for i, f in enumerate(self._values):
            if f.term == artist_name:
                return i
        return 0

    # QAbstractListModel compliance code
    def rowCount(self, parent=QModelIndex()):
        return self._count

    def data(self, index, role, roles=ROLES):
        if not index.isValid():
            return None

        rolev = self.ROLES[role]
        facet = self._values[index.row()]

        if rolev == self.ROLE_ARTIST_NAME:
            return str(facet.term).decode("utf-8", "ignore")
        elif rolev == self.ROLE_TERM_FREQ:
            return facet.termfreq
        return None

    @pyqtProperty(int, notify=allCountChanged)
    def all_termfreq(self):
        return self._tot
