import QtQuick 1.1
import QtDesktop 0.1


Rectangle {
    id: bg

    property int nRows: Math.min(2, Math.ceil(grid.count / Math.floor((width-12)/grid.cellWidth)))

    height: nRows > 0 ? nRows * grid.cellHeight : 0
    Behavior on height {PropertyAnimation {duration: 200} }
    color: "#EBE4DF"

    GridView {
        id: grid

        clip: true
        boundsBehavior: Flickable.StopAtBounds
        model: Collection.albums

        anchors.fill: parent

        cellWidth: 150
        cellHeight: 150

        header: Item {
            height: 50
            width: 1
        }

        footer: Item {height: 12; width: 1;}

        delegate: Item {
            property string album: _album
            property string art: _art
            property string artist: _artist
            property int ntracks: _ntracks
            //property string similar: _artsim

            width: 215
            height: 100

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    grid.forceActiveFocus()
                    Collection.filter_current_query_by_album(album)
                }
                onDoubleClicked: {
                    grid.forceActiveFocus()
                    Player.next()
                }
            }

            Rectangle {
                id: cover

                width: 82
                anchors.top: parent.top
                anchors.topMargin: 12
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter

                border.color: "black"
                border.width: 1
            }

            Image {
                anchors.fill: cover
                anchors.topMargin: 1
                anchors.leftMargin: 1
                fillMode: Image.PreserveAspectCrop
                source: art
                visible: art != ""
                smooth: true
                clip: true

                Bubble {
                    text: ntracks
                    anchors.bottom: parent.bottom
                    anchors.right: parent.right
                    anchors.bottomMargin: 3
                    anchors.rightMargin: 3
                    visible: ntracks > 0
                    highlightFactor: 2.25
                    baseColor: "#FF3333"
                }
            }

            TextLabel {
                id: albumName

                width: 135
                text: album
                font.pointSize: 8
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.topMargin: 6
                anchors.top: cover.bottom
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.Wrap
                elide: Text.ElideRight
                maximumLineCount: 2
            }

            Text {
                width: 135
                text: artist
                font.pointSize: 8
                font.bold: true
                color: activePalette.mid
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                anchors.topMargin: 4
                anchors.top: albumName.bottom
                elide: Text.ElideRight
            }
        }
    }

    Item {
        id: albumHeader

        height: 50
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.top: parent.top

        Image {
            anchors.left: parent.left
            anchors.right: parent.right
            source: "../../../data/art/fade-out.png"
        }

        Column {
            anchors.fill: parent
            anchors.margins: 12
            spacing: 4

            Row {
                spacing: 6

                ListViewButton {
                    label: "e"
                    radius: 6
                    font.family: "TotallyWired"
                    font.pixelSize: 16
                    height: similarArtists.y + similarArtists.paintedHeight
                    
                    onClicked: Collection.reset_current_artist_query()
                }

                TextLabel {
                    font.bold: true
                    font.pixelSize: 12
                    text: Collection.albums.title
                    onTextChanged: grid.positionViewAtBeginning()
                    
                    Text {
                        id: similarArtists

                        text: Collection.albums.similarArtistsLinks
                        color: "#FF3333"
                        font.pixelSize: 10
                        wrapMode: Text.Wrap
                        textFormat: Text.RichText
                        width: albumHeader.width - 100
                        
                        anchors.top: parent.bottom
                        anchors.topMargin: 4

                        onLinkActivated: {
                            searchentry.autoPing = false
                            searchentry.text = ""
                            searchentry.autoPing = true
                            Collection.handle_link(link)
                        }

                        Behavior on text {
                            SequentialAnimation {
                                NumberAnimation { target: similarArtists; property: "opacity"; to: 0 }
                                PropertyAction {}
                                NumberAnimation { target: similarArtists; property: "opacity"; to: 1 }
                            }
                        }

                        ListViewButton {
                            x: parent.x + parent.paintedWidth + 6
                            anchors.verticalCenter: parent.verticalCenter
                            label: "k"
                            font.family: "TotallyWired"
                            //baseColor: "#FF3333"
                            visible: Collection.albums.hasSimilarArtistsInCollection && parent.text
                            radius: 6
                            verticalPadding: 0
                            horizontalPadding: 3
                            font.pixelSize: 11

                            onClicked: {
                                Collection.generate_similar_playlist()
                                Player.next()
                            }
                        }
                    }
                }
            }
        }
    }

    Image {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        source: "../../../data/art/dropshadow-south.png"
        opacity: 0.8
    }

    Scrollbar {
        id: scrollbar
        anchors.right: parent.right
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.margins: 3
        scrollArea: grid
    }

}
