import QtQuick 1.1

Item {
    Rectangle {
        anchors.fill: parent
        color: "#D1C7BC"
    }

    ListView {
        id: list

        clip: true
        boundsBehavior: Flickable.StopAtBounds
        model: Collection.albums

        anchors.fill: parent

        onCountChanged: {
            currentIndex = 0
        }

        delegate: Rectangle {
            id: row
            clip: true

            property string album: _album
            property string termfreq: _termfreq
            property alias label: col0

            height: 2.5 * em
            width: list.width

            color: {
                if (ListView.isCurrentItem) {
                    return "#FF9C5B"
                }
                else {
                    return "#D1C7BC"
                }
            }

            MouseArea {
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton
                //hoverEnabled: true

                onClicked: {
                    if (list.currentIndex != index)
                        list.currentIndex = index
                    list.forceActiveFocus()
                    if (list.count > 1) {
                        Collection.filter_current_query_by_album(album)
                    }
                 }

                onDoubleClicked: {
                    if (list.currentIndex != index)
                        list.currentIndex = index
                    list.forceActiveFocus()
                    Player.next()
                }
            }

            Text {
                // album
                id: col0
                color: list.currentIndex == index ? Qt.lighter(row.color, 1.8) : Qt.darker(row.color, 3)
                text: album
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: list.currentIndex == index ? Qt.darker(row.color, 1.8) : Qt.lighter(row.color, 1.3)
                x: 6
                y: 10
                width: parent.width - (parent.width - bubble.x) - 6
            }

            Bubble {
                id: bubble

                text: termfreq
                visible: termfreq > 0
                anchors.right: parent.right
                anchors.verticalCenter: col0.verticalCenter
                anchors.rightMargin: albumScrollbar.opacity > 0 ? 14 : 6
                baseColor: row.color
            }
        }

        Rectangle {
            id: floatingAllAlbums

            property bool allAlbumsSelected: list.currentIndex == 0

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: 2.5 * em

            color: {
                if (allAlbumsSelected && list.currentItem != null)
                    list.currentItem.color
                else
                    "#D1C7BC"
            }

            opacity: list.contentY <= 0 ? 0 : 1
            //Behavior on opacity { PropertyAnimation {duration: 500} }

            Text {
                // all artists
                id: aaText
                text: "<b>All Albums</b>"
                color: parent.allAlbumsSelected ? Qt.lighter(parent.color, 1.8) : Qt.darker(parent.color, 3)
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: parent.allAlbumsSelected ? Qt.darker(parent.color, 1.8) : Qt.lighter(parent.color, 1.3)
                x: 6
                y: 10
                width: parent.width - 12
            }

            Bubble {
                id: aaBubble

                text: Collection.albums.all_termfreq
                anchors.right: parent.right
                anchors.verticalCenter: aaText.verticalCenter
                anchors.rightMargin: albumScrollbar.opacity > 0 ? 14 : 6
                baseColor: floatingAllAlbums.color
            }

            Image {
                source: "../../../data/art/dropshadow-north.png"
                anchors.top: floatingAllAlbums.bottom
                anchors.left: floatingAllAlbums.left
                width: parent.width
                opacity: list.contentY <= 0 ? 0 : 1
                Behavior on opacity { PropertyAnimation {duration: 250} }
            }

            MouseArea {
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton
                //hoverEnabled: true

                onClicked: {
                    list.currentIndex = 0
                    list.positionViewAtIndex(0, ListView.Visible)
                    Collection.filter_current_query_by_album("<b>All Albums</b>")
                }
            }
        }

        Scrollbar {
            id: albumScrollbar
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.margins: 3
            scrollArea: list
        }
    }
}
