import QtQuick 1.1


Item {
    Rectangle {
        anchors.fill: parent
        color: "#BFB6AC"
    }

    ListView {
        id: list

        clip: true
        boundsBehavior: Flickable.StopAtBounds
        model: Collection.artists

        property int currentArtist: Collection.current_artist_index

        onCurrentArtistChanged: {
            console.log(currentArtist)
            currentIndex = currentArtist
            list.positionViewAtIndex(currentArtist, ListView.Center)
        }

        anchors.fill: parent

        delegate: Rectangle {
            id: row
            clip: true

            property string artist: _artist
            property string termfreq: _termfreq
            property alias label: col0

            height: 2.5 * em
            width: list.width

            color: {
                if (ListView.isCurrentItem) {
                    return "#FF9C5B"
                }
                else {
                    return "#BFB6AC"
                }
            }

            MouseArea {
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton
                //hoverEnabled: true

                onClicked: {
                    if (list.currentIndex != index)
                        list.currentIndex = index
                    list.forceActiveFocus()
                    Collection.filter_current_query_by_artist(artist)
                 }

                onDoubleClicked: {
                    if (list.currentIndex != index)
                        list.currentIndex = index
                    list.forceActiveFocus()
                    Player.next()
                }
            }

            Text {
                // artist
                id: col0
                color: list.currentIndex == index ? Qt.lighter(row.color, 1.8) : Qt.darker(row.color, 3)
                text: artist
                font.pointSize: 9
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: list.currentIndex == index ? Qt.darker(row.color, 1.8) : Qt.lighter(row.color, 1.3)
                x: 6
                y: 10
                width: parent.width - (parent.width - bubble.x) - 6
            }

            Bubble {
                id: bubble

                text: termfreq
                visible: termfreq > 0
                anchors.right: parent.right
                anchors.verticalCenter: col0.verticalCenter
                anchors.rightMargin: artistScrollbar.opacity > 0 ? 14 : 6
                baseColor: row.color
            }
        }

        Rectangle {
            id: floatingAllArtists

            property bool allArtistsSelected: list.currentIndex == 0

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            height: 2.5 * em

            color: {
                if (allArtistsSelected)
                    list.currentItem.color
                else
                    Qt.darker("#BFB6AC", 1.1)
            }

            opacity: list.contentY <= 0 ? 0 : 1
            //Behavior on opacity { PropertyAnimation {duration: 500} }

            Text {
                // all artists
                id: aaText
                text: "<b>All Artists</b>"
                color: parent.allArtistsSelected ? Qt.lighter(parent.color, 1.8) : Qt.darker(parent.color, 3)
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: parent.allArtistsSelected ? Qt.darker(parent.color, 1.8) : Qt.lighter(parent.color, 1.3)
                font.pointSize: 9
                x: 6
                y: 10
                width: parent.width - 12
            }

            Bubble {
                id: aaBubble
                text: Collection.artists.all_termfreq
                anchors.right: parent.right
                anchors.verticalCenter: aaText.verticalCenter
                anchors.rightMargin: artistScrollbar.opacity > 0 ? 14 : 6
                baseColor: floatingAllArtists.color
            }

            Image {
                source: "../../../data/art/dropshadow-north.png"
                anchors.top: floatingAllArtists.bottom
                anchors.left: floatingAllArtists.left
                width: parent.width
                opacity: list.contentY <= 0 ? 0 : 1
                Behavior on opacity { PropertyAnimation {duration: 250} }
            }

            MouseArea {
                anchors.fill: parent
                acceptedButtons: Qt.LeftButton
                //hoverEnabled: true

                onClicked: {
                    list.currentIndex = 0
                    list.positionViewAtIndex(0, ListView.Visible)
                    Collection.filter_current_query_by_artist(aaText.text)
                }
            }
        }

        Scrollbar {
            id: artistScrollbar
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.margins: 3
            scrollArea: list
        }
    }
}
