import QtQuick 1.1
import QtDesktop 0.1


Item {
    TrackList {
        id: list
        objectName: "cddaView"

        anchors.top: cddaHeader.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        model: Collection.cdda
        delegate: MusicCollectionListDelegate {}
    }

    Rectangle {
        // no content splash

        anchors.fill: parent
        visible: list.count == 0

        TextLabel {
            id: noResults
            text: "No Audio CD present"

            font.bold: true
            font.pointSize: 12
            anchors.centerIn: parent
        }
    }

    Rectangle {
        id: cddaHeader

        color: "#BFB6AC"
        height: 220

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right

        opacity: list.count > 0 ? 1 : 0
        Behavior on opacity { PropertyAnimation {duration: 150} }

        Image {
            source: "../../../data/art/white-faint-gradient.png"

            width: parent.width
            anchors.left: parent.left
            anchors.bottom: parent.bottom
        }

        Image {
            id: albumArt

            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
            anchors.leftMargin: 18

            source: "../../../data/art/140x140-album-bg.png"

            Image {
                asynchronous: true
                source: Collection.cdda.album_art_url

                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: 8
                anchors.leftMargin: 9

                width: parent.width - 19
                height: parent.width - 19
            }
        }

        Column {
            anchors.left: albumArt.right
            anchors.right: parent.right
            anchors.top: albumArt.top
            anchors.leftMargin: 12
            anchors.rightMargin: 12
            anchors.topMargin: 6

            spacing: 6

            TextField {
                id: artist
                anchors.left: parent.left
                anchors.right: parent.right
                placeholderText: "Unknown"
                text: Collection.cdda.artist

                Text {
                    color: Qt.darker(activePalette.mid, 1.6)
                    text: "<small>ARTIST CREDIT</small>"
                    style: Text.Raised
                    styleColor: Qt.lighter(activePalette.mid, 1.1667)
                    font.bold: true
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    anchors.rightMargin: 10
                }
            }

            TextField {
                id: album
                placeholderText: "Unknown"
                anchors.left: parent.left
                anchors.right: parent.right
                text: Collection.cdda.album

                Text {
                    color: Qt.darker(activePalette.mid, 1.6)
                    text: "<small>ALBUM NAME</small>"
                    style: Text.Raised
                    styleColor: Qt.lighter(activePalette.mid, 1.1667)
                    font.bold: true
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.right: parent.right
                    anchors.rightMargin: 10
                }
            }

            Row {
                anchors.left: parent.left
                anchors.right: parent.right
                spacing: 6

                TextField {
                    id: date
                    placeholderText: "Unknown"
                    text: Collection.cdda.date

                    Text {
                        color: Qt.darker(activePalette.mid, 1.6)
                        text: "<small>RELEASE DATE</small>"
                        style: Text.Raised
                        styleColor: Qt.lighter(activePalette.mid, 1.1667)
                        font.bold: true
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.right: parent.right
                        anchors.rightMargin: 10
                    }
                }

                TextField {
                    id: tags
                    width: parent.width - date.width - 6
                    placeholderText: "No tags"
                    text: Collection.cdda.tags

                    Text {
                        color: Qt.darker(activePalette.mid, 1.6)
                        text: "<small>TAGS</small>"
                        style: Text.Raised
                        styleColor: Qt.lighter(activePalette.mid, 1.1667)
                        font.bold: true
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.right: parent.right
                        anchors.rightMargin: 10
                    }
                }

            }

            Row {
                property int discCount: Collection.cdda.disc_count
                opacity: discCount > 1
                spacing: 6

                TextLabel {
                    anchors.verticalCenter: parent.verticalCenter
                    text: "This release contains multiple discs.  Which disc do you currently have loaded?"
                }

                ComboBox {
                    id: discNum
                    width: 80

                    MenuItem {
                        text: "Disc 1"
                        onTriggered: {
                            if (!Collection.cdda.working) {
                                discNum.selectedIndex = 0
                                Collection.cdda.set_disc_number(0)
                            }
                        }
                    }

                    MenuItem {
                        text: "Disc 2"
                        onTriggered: {
                            if (!Collection.cdda.working) {
                                discNum.selectedIndex = 1
                                Collection.cdda.set_disc_number(1)
                            }
                        }
                    }

                    selectedIndex: Collection.cdda.disc_number
                }
            }
        }

//        Button {
//            id: mbSave

//            anchors.bottom: albumArt.bottom
//            anchors.left: albumArt.right
//            anchors.leftMargin: 12
//            anchors.bottomMargin: 9

//            text: "Save"

//            onClicked: {
//            }
//        }

        Button {
            id: mbSearch

            anchors.bottom: albumArt.bottom
            anchors.left: albumArt.right
            anchors.leftMargin: 12
            anchors.bottomMargin: 9

            text: "Search"
            opacity: Collection.cdda.working || (Collection.cdda.artist == artist.text && Collection.cdda.album == album.text) ? 0.333 : 1.0

            onClicked: {
                if (opacity >= 1.0)
                    Collection.cdda.release_lookup(album.text, artist.text, 0)
            }
        }

        LabelButton {
            id: mbReset

            anchors.top: mbSearch.top
            anchors.bottom: mbSearch.bottom
            anchors.left: mbSearch.right
            anchors.leftMargin: 2

            font.family: "TotallyWired"
            label: "g"
            opacity: Collection.cdda.working || (Collection.cdda.artist == artist.text && Collection.cdda.album == album.text) ? 0.333 : 1.0

            onClicked: {
                if (opacity >= 1.0) {
                    artist.text = Collection.cdda.artist
                    album.text = artist.text
                }
            }
        }

        Button {
            id: cdImport

            anchors.bottom: mbSearch.bottom
            anchors.right: parent.right
            anchors.rightMargin: 12

            text: "Import Audio CD"

            onClicked: {
            }
        }

        Image {
            source: "../../../data/art/dropshadow-north.png"
            width: parent.width
            anchors.top: cddaHeader.bottom
            anchors.left: parent.left
        }
    }

    Rectangle {
        id: workingBubble

        radius: 20
        opacity: Collection.cdda.working ? 1 : 0
        color: Qt.rgba(0,0,0,0.85)
        width: children[1].paintedWidth + 6*em
        height: children[1].paintedHeight + 5*em

        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottomMargin: 36

        Behavior on opacity { PropertyAnimation {duration: 333} }

        BorderImage {
            source: "../../../data/art/bg.png"
            border { left: 29; top: 29; right: 29; bottom: 29 }
            anchors.fill: parent
            anchors.margins: 5
            opacity: 0.85
        }

        Text {
            text: "Fetching Audio CD information"
            color: Qt.rgba(1,1,1,0.85)
            font.bold: true
            style: Text.Raised
            styleColor: "black"
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenterOffset: -3
        }

        Item {
            width: 30; height: 6;

            anchors.top: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.topMargin: 12

            Rectangle {
                id: throbber

                width: 6
                height: 6
                radius: 3
                color: Qt.rgba(1,1,1, 0.85)

                SequentialAnimation {
                    loops: Animation.Infinite
                    running: workingBubble.opacity > 0
                    NumberAnimation { target: throbber; property: "x"; to: 24; duration: 750 }
                    NumberAnimation { target: throbber; property: "x"; to: 0; duration: 750 }
                }
            }
        }
    }
}
