import QtQuick 1.1

// like dislike button
FocusScope {
    id: button

    property alias likeLabel: likeText.text
    property alias dislikeLabel: dislikeText.text
    property color baseColor: Qt.rgba(1,1,1,1)

    property int verticalPadding: 3
    property int horizontalPadding: 10

    height: verticalPadding*2 + likeText.paintedHeight
    width: horizontalPadding*2 + dislikeText.paintedWidth + likeText.paintedWidth

    property alias bg: bg

    signal dislikeClicked
    signal likeClicked

    Rectangle {
        id: bg
        anchors.fill: parent
        radius: Math.min(width, height) * 0.5
        opacity: button.opacity
        color: Qt.darker(baseColor, 1.35)
        border.width: 1
        border.color: Qt.darker(baseColor, 1.55)
        clip: true

        Behavior on width { PropertyAnimation {duration: 150} }

        Row {
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenterOffset: 1

            Text {
                id: likeText
                anchors.verticalCenter: parent.verticalCenter
                color: likeArea.containsMouse ? Qt.lighter(baseColor, 2) : Qt.lighter(baseColor, 1.35)
                font.pointSize: 9
                font.bold: true
                text: "Like"
                style: Text.Raised
                styleColor: Qt.darker(baseColor, 2)

                MouseArea {
                    id: likeArea
                    anchors.fill: parent
                    hoverEnabled: true

                    onClicked: {
                        button.likeClicked()
                    }
                }
            }

            Rectangle {
                width: 1
                color: Qt.rgba(0,0,0,0.15)
                anchors.top: parent.top
                anchors.bottom: parent.bottom
            }

            Text {
                id: dislikeText
                anchors.verticalCenter: parent.verticalCenter
                color: dislikeArea.containsMouse ? Qt.lighter(baseColor, 2) : Qt.lighter(baseColor, 1.45)
                font.pointSize: 9
                font.bold: true
                text: "Dislike"
                style: Text.Raised
                styleColor: Qt.darker(baseColor, 2)

                MouseArea {
                    id: dislikeArea
                    anchors.fill: parent
                    hoverEnabled: true

                    onClicked: {
                        button.dislikeClicked()
                    }
                }
            }
        }
    }
}
