import QtQuick 1.1


Item {
    id: container
    property alias containsMouse: events.containsMouse

    implicitHeight: bg.height

    Rectangle {
        id: bg
        color: "#C3B3B9"
        height: 3

        anchors.fill: parent

        Rectangle {
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            width: Player.playback_position * parent.width
            color: "#ED303C"

            Behavior on width { PropertyAnimation {duration: 100} }
        }

        AnimatedImage {
            anchors.topMargin: 1
            anchors.leftMargin: 1
            anchors.fill: parent
            source: "../../../data/art/streaming.gif"
            visible: Player.is_buffering_or_streaming
            fillMode: Image.TileHorizontally
            opacity: 0.1
        }

        MouseArea {
            id: events
            hoverEnabled: Player.duration_known

            anchors.left: bg.left
            anchors.right: bg.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.topMargin: -6
            anchors.bottomMargin: -6

            onMouseXChanged: {
                if (mouseX < bubble.width/2)
                    bubble.x = Math.max(
                        parent.x + mouseX - bubble.width/2,
                        parent.x - 10
                    )
                else if (mouseX > bg.width - bubble.width/2)
                    bubble.x = Math.min(
                        parent.x + mouseX - bubble.width/2,
                        parent.x + bg.width - bubble.width + 10
                    )
                else if (mouseX >= bubble.width/2)
                    bubble.x = parent.x + mouseX - bubble.width/2

                pointer.x = mouseX - bubble.x + parent.x - pointer.width/2
                postime.text = Player.position_to_time(mouseX / bg.width)
            }

            onClicked: {
                if (Player.duration_known)
                    Player.set_position(mouseX / bg.width)
            }
        }
    }

    Rectangle {
        id: bubble
        color: "#363430"
        border.width: 1
        border.color: "black"
        radius: 5
        opacity: Player.duration_known & events.containsMouse ? 1 : 0
        width: postime.paintedWidth + 12
        height: postime.paintedHeight + 6
        y: -height - 6

        Behavior on opacity { PropertyAnimation {duration: 100} }

        Text {
            id: postime
            anchors.centerIn: parent
            color: "white"
            style: Text.Raised
            styleColor: "black"
        }

        Image {
            id: pointer
            source: "../../../data/art/s-pointer.png"
            anchors.top: parent.bottom
        }
    }
}
