import QtQuick 1.1


TrackListDelegate {
    id: row

    property int startY: 0
    property bool dragActive: mouseArea.drag.active
    property bool pressed: mouseArea.pressed

    z: dragActive ? 3 : 0
    border.width: dragActive ? 1 : 0
    border.color: Qt.darker(color, 1.3)

    mouseArea.drag.target: isCurrentStream || list.count == 1 ? null : row

    onDragActiveChanged: {
        if (dragActive)
            list.model.update_selection(index, 0)
    }

    onPressedChanged: {
        if (mouseArea.pressed) {
            startY = row.y
        }
        else {
            var to = Queue.shift_selected(
                (row.y + mouseArea.mouseY - startY) / row.height)   // dy
            if (to == -1) {
                row.y = startY
                row.x = 0
            }
        }
    }


    Row {
        spacing: 3
        
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter

        Text {
            // queue pos
            id: content
            color: text_color
            text: "<i>" + (index + 1) + ".</i>"
            font.pointSize: _pointSize
            width: list.tracknColWidth
            horizontalAlignment: Text.AlignHCenter
            style: Text.Raised
            styleColor: textstyle_color
        }

        Item {
            width: list.titleColWidth
            height: children[0].implicitHeight

            Text {
                // track title
                color: text_color
                width: parent.width - 3
                text: title
                font.pointSize: _pointSize
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
                font.bold: isCurrentStream

                Row {
                    x: parent.paintedWidth + 3
                    anchors.verticalCenter: parent.verticalCenter
                    spacing: 2

                    Text {
                        // heart
                        visible: liked == 1
                        anchors.verticalCenter: parent.verticalCenter
                        text: "\u2665"
                        smooth: false
                        color: text_color
                        style: Text.Raised
                        styleColor: textstyle_color
                        font.pixelSize: 9
                    }

                    Text {
                        // scullxbones
                        visible: liked == 2
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 1
                        text: "a"
                        font.family: "TotallyWired"
                        smooth: false
                        color: text_color
                        style: Text.Raised
                        styleColor: textstyle_color
                        font.pointSize: 8
                        font.bold: true
                    }
                }
            }
        }

        Item {
            width: list.albumColWidth
            height: children[0].implicitHeight

            Text {
                // album name
                color: text_color
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - 3
                font.pointSize: _pointSize
                text: album
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
            }
        }

        Item {
            width: list.artistColWidth
            height: children[0].implicitHeight

            Text {
                // artist name
                color: text_color
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - 3
                font.pointSize: _pointSize
                text: artist
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
            }
        }

        Text {
            // duration
            color: text_color
            anchors.verticalCenter: parent.verticalCenter
            width: list.durationColWidth
            text: duration
            font.pointSize: _pointSize
            style: Text.Raised
            styleColor: textstyle_color
        }

        Text {
            // tags
            color: text_color
            anchors.verticalCenter: parent.verticalCenter
            text: tags
            font.pointSize: _pointSize
            style: Text.Raised
            styleColor: textstyle_color
            font.bold: isCurrentStream
        }
    }

    ListView.onRemove: SequentialAnimation {
        PropertyAction { target: row; property: "ListView.delayRemove"; value: true }
        PropertyAction { target: row; property: "opacity"; value: 0 }
        NumberAnimation { target: row; property: "height"; to: 0; duration: 150; easing.type: Easing.InOutQuad }
        // Make sure delayRemove is set back to false so that the item can be destroyed
        PropertyAction { target: row; property: "ListView.delayRemove"; value: false }
    }

}
