/*
 * Copyright 2011 Canonical Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier@tilloy.net>
 *  Michael Vogt <mvo@ubuntu.com>
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import QtDesktop 0.1


FocusScope {
    id: listview

    Rectangle {
        id: queueHeader

        clip: true
        color: "#BFB6AC"
        height: button.height + 24

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right

        Image {
            source: "../../../data/art/white-faint-gradient.png"

            width: parent.width
            anchors.left: parent.left
            anchors.bottom: parent.bottom
        }

        Text {
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 12

            color: Qt.darker(parent.color, 1.4)
            style: Text.Raised
            styleColor: Qt.lighter(parent.color, 1.25)
            text: "<small>Tip: You can Drag 'n' Drop to reorder the queue</small>"

            opacity: Queue.count > 1 ? 1 : 0
            Behavior on opacity { PropertyAnimation {duration: 300} }
        }

        Button {
            id: button
            text: "Clear all"

            anchors.right: parent.right
            anchors.verticalCenter: parent.verticalCenter
            anchors.rightMargin: 12

            onClicked: Queue.empty()
        }
    }

    TrackList {
        id: list
        objectName: "queueView"

        anchors.top: queueHeader.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        model: Queue
        delegate: QueueListDelegate {}
    }

    Image {
        source: "../../../data/art/dropshadow-north.png"
        width: parent.width
        anchors.top: queueHeader.bottom
        anchors.left: parent.left
    }

    Rectangle {
        // no cdda inserted splash

        anchors.fill: parent
        visible: list.count == 0

        TextLabel {
            id: noResults
            text: "There are no songs currently queued"

            font.bold: true
            font.pointSize: 12
            anchors.centerIn: parent
        }

    }
}
