import QtQuick 1.1
import QtDesktop 0.1

Item {
    ListView {
        id: stations
        model: Stations

        clip: true
        boundsBehavior: Flickable.StopAtBounds

        width: Math.min(800, parent.width)
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: radioHeader.bottom
        anchors.bottom: parent.bottom

        spacing: 6

        header: Item {
            height: 24
            width: 1
        }

        delegate: Rectangle {
            id: row

            property string source: _source
            property string srcicon: _srcicon
            property string srcname: _srcname
            property bool is_playing: _is_playing

            radius: 5
            clip: true

            color: {
                if (is_playing)
                    return "#4D85CF"
                else 
                    return "#BFB6AC"
            }

            Behavior on color { PropertyAnimation {duration: 300} }

            anchors.horizontalCenter: parent.horizontalCenter
            height: 70
            width: Math.min(800, parent.width)

            Image {
                id: icon
                //smooth: true
                source: "../../../data/art/faenza/empty.png"
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: parent.left
                anchors.leftMargin: 12

                z: 1

                Image {
                    anchors.centerIn:parent
                    source: srcicon
                }
            }

            Column {
                anchors.verticalCenter: parent.verticalCenter
                anchors.left: icon.right
                anchors.right: parent.right

                z: 1
                anchors.margins: 12
                spacing: 6

                Text {
                    // name
                    anchors.left: parent.left
                    anchors.right: parent.right
                    color: Qt.darker(row.color, 2.2)
                    font.bold: true
                    font.pointSize: 12
                    text: srcname
                    style: Text.Raised
                    styleColor: Qt.lighter(row.color, 1.225)
                }

                Text {
                    // source path
                    anchors.left: parent.left
                    anchors.right: parent.right
                    color: Qt.darker(row.color, 2.2)
                    text: "<small>" + source + "</small>"
                    style: Text.Raised
                    styleColor: Qt.lighter(row.color, 1.225)
                }
            }

            Row {
                anchors.margins: 12
                anchors.right: parent.right
                anchors.top: parent.top

                Behavior on opacity { PropertyAnimation {duration: 300} }

                ListViewButton {
                    label: is_playing ? "m" : "k"
                    font.family: "TotallyWired"
                    font.pixelSize: 20
                    verticalPadding: 4
                    horizontalPadding: 4
                    baseColor: row.color

                    onClicked: {
                        if (is_playing)
                            Stations.stop(index)
                        else
                            Stations.start(index)
                    }
                }

                ListViewButton {
                    label: "f"
                    font.family: "TotallyWired"
                    font.pixelSize: 20
                    verticalPadding: 4
                    horizontalPadding: 4
                    baseColor: row.color

                    onClicked: {
                        okLoader.source = "InlineOkDialog.qml"
                    }
                }
            }

            ListView.onAdd: SequentialAnimation {
                PropertyAction { target: row; property: "height"; value: 0 }
                NumberAnimation { target: row; property: "height"; to: 100; duration: 150; easing.type: Easing.InOutQuad }
            }

            ListView.onRemove: SequentialAnimation {
                PropertyAction { target: row; property: "ListView.delayRemove"; value: true }
                NumberAnimation { target: row; property: "height"; to: 0; duration: 150; easing.type: Easing.InOutQuad }
                // Make sure delayRemove is set back to false so that the item can be destroyed
                PropertyAction { target: row; property: "ListView.delayRemove"; value: false }
            }

            Loader {
                id: okLoader
                anchors.fill: parent
                z: 3
            }

            Connections {
                target: okLoader.item
                onYesClicked: {
                    okLoader.source = ""
                    Stations.remove_station(index)
                }
                onNoClicked: {
                    okLoader.source = ""
                }
            }
        }

        footer: Item {
            height: 24
        }
    }

    Item {
        id: radioHeader
        height: addStationBtn.y + addStationBtn.height + 12 + 36 + 12
        anchors.horizontalCenter: parent.horizontalCenter
        width: Math.min(800, parent.width)

        Column {
            spacing: 12

            anchors.top: parent.top
            width: parent.width

            anchors.topMargin: 36

            Row {
                id: addStation

                spacing: 3
                height: children[0].height
                width: parent.width

                TextEntryField {
                    id: stationEntry
                    placeholderText: "<i>Network URL goes here... e.g. http://www.eg.com/stream.asx</i>"
                    idleIcon: ""
                    width: 500
                    height: addStationBtn.height + 2
                }

                Button {
                    id: addStationBtn
                    anchors.verticalCenter: addStation.verticalCenter
                    text: "Add stream"
                    
                    opacity: stationEntry.text.length > 0 ? 1 : 0.3

                    onClicked: Stations.add_station(stationEntry.text)
                }
            }
        }

        Image {
            source: "../../../data/art/dropshadow-fadeout-left.png"
            anchors.top: radioHeader.bottom
            anchors.right: dropShadow.left
        }

        Image {
            source: "../../../data/art/dropshadow-fadeout-right.png"
            anchors.top: radioHeader.bottom
            anchors.left: dropShadow.right
        }

        Image {
            id: dropShadow
            source: "../../../data/art/dropshadow-north.png"
            width: parent.width
            anchors.top: radioHeader.bottom
            anchors.left: parent.left
        }
    }
}
