 /****************************************************************************
 **
 ** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtDeclarative module of the Qt Toolkit.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
 ** GNU Lesser General Public License Usage
 ** This file may be used under the terms of the GNU Lesser General Public
 ** License version 2.1 as published by the Free Software Foundation and
 ** appearing in the file LICENSE.LGPL included in the packaging of this
 ** file. Please review the following information to ensure the GNU Lesser
 ** General Public License version 2.1 requirements will be met:
 ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
 ** In addition, as a special exception, Nokia gives you certain additional
 ** rights. These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU General
 ** Public License version 3.0 as published by the Free Software Foundation
 ** and appearing in the file LICENSE.GPL included in the packaging of this
 ** file. Please review the following information to ensure the GNU General
 ** Public License version 3.0 requirements will be met:
 ** http://www.gnu.org/copyleft/gpl.html.
 **
 ** Other Usage
 ** Alternatively, this file may be used in accordance with the terms and
 ** conditions contained in a signed written agreement between you and Nokia.
 **
 **
 **
 **
 **
 **
 **
 ** Modified for purpose on 21/2/2011 by Matthew McGowan
 **
 ****************************************************************************/

import QtQuick 1.1

Item {
    id: container

    property variant scrollArea
    property variant orientation: Qt.Vertical

    visible: rect.height < height
    width: 6

    function position()
    {
        var ny = 0;
        if (container.orientation == Qt.Vertical)
            ny = scrollArea.visibleArea.yPosition * container.height;
        else
            ny = scrollArea.visibleArea.xPosition * container.width;
        return Math.max(0, ny)
    }

    function size() {
        if (container.orientation == Qt.Vertical)
            return scrollArea.visibleArea.heightRatio * container.height;
        return scrollArea.visibleArea.widthRatio * container.width;
    }

    Rectangle {
        anchors.fill: parent;
        color: Qt.rgba(0,0,0,0.1);
        opacity: container.scrollArea.moving || events.containsMouse || events.drag.active ? 1.0 : 0.0
        radius: 3

        Behavior on opacity { PropertyAnimation {duration: 500} }
    }

    Rectangle {
        id: rect
        radius: 3
        color: Qt.rgba(0,0,0,0.7)
        opacity: container.scrollArea.moving || events.containsMouse || events.drag.active ? 1.0 : 0.333
        x: container.orientation == Qt.Vertical ? 0 : position()
        width: container.orientation == Qt.Vertical ? container.width : size()
        y: container.orientation == Qt.Vertical ? position() : 0
        height: container.orientation == Qt.Vertical ? Math.max(10, size()) : container.height

        Behavior on opacity { PropertyAnimation {duration: 500} }

        MouseArea {
            id: events
            anchors.fill: parent
            drag.target: rect
            drag.axis: Drag.YAxis
            drag.minimumY: 0
            drag.maximumY: container.height - rect.height
            hoverEnabled: true

            onMouseYChanged: {
                if (pressed && container.orientation == Qt.Vertical) {
                    scrollArea.contentY = rect.y / container.height * scrollArea.contentHeight
                }
            }
        }
    }
}
