import QtQuick 1.1
import QtDesktop 0.1


Rectangle {
    id: bg

    property int nRows: Math.min(3, Math.ceil(grid.count / Math.floor((width-12)/grid.cellWidth)))
    property alias model: grid.model

    height: Collection.artist_filter_active && nRows > 0 ? nRows * 60 + 12 : 0
    color: "#EBE4DF"

    Image {
        clip: true
        anchors.fill: parent
        source: "../../../data/art/white-faint-gradient.png"

        Image {
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            source: "../../../data/art/dropshadow-south.png"
            opacity: 0.8
        }
    }

    GridView {
        id: grid

        clip: true
        boundsBehavior: Flickable.StopAtBounds

        anchors.fill: parent
        anchors.margins: 6

        cellWidth: 215
        cellHeight: 60

        delegate: Item {
            property string art: _art
            property string track: _track
            property string artist: _artist

            width: 215
            height: 60

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    grid.forceActiveFocus()
                }

                onDoubleClicked: {
                    grid.forceActiveFocus()
                }
            }

            Rectangle {
                id: cover

                width: 52
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: parent.left
                anchors.topMargin: 4
                anchors.bottomMargin: 4
                anchors.leftMargin: 4

                border.color: "black"
                border.width: 1
            }

            Image {
                anchors.fill: cover
                anchors.topMargin: 1
                anchors.leftMargin: 1
                fillMode: Image.PreserveAspectCrop
                source: art
                visible: art != ""
                smooth: true
                clip: true
            }

            TextLabel {
                width: 135

                text: artist
                font.pointSize: 8
                anchors.left: cover.right
                anchors.leftMargin: 6
                anchors.topMargin: 2
                anchors.top: cover.top
                wrapMode: Text.Wrap
                elide: Text.ElideRight
                maximumLineCount: 2
            }
        }

        Scrollbar {
            id: scrollbar
            anchors.right: parent.right
            anchors.top: parent.top
            anchors.bottom: parent.bottom
            anchors.margins: 3
            scrollArea: grid
        }
    }
}
