/*
 * Copyright 2011 Canonical Ltd.
 *
 * Authors:
 *  Olivier Tilloy <olivier@tilloy.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import QtDesktop 0.1

TextField {
    id: textField

    property string uText: ""
    property bool noDelay: false
    property int minWidth: 200
    property bool autoPing: true
    
    property string idleIcon: "../../../data/art/faenza/small/edit-find.svg"
    property string clearIcon: "../../../data/art/faenza/small/edit-clear.svg"

    width: Math.max(minWidth, text.length * 10)

    placeholderText: "<i>Search your music collection</i>"

    Behavior on width { PropertyAnimation {duration: 100} }

    Timer {
        id: timeout
        running: false; repeat: false;
        onTriggered: {
            if (noDelay)
                noDelay = false // consume noDelay
            textField.uText = textField.text
        }
    }

    onTextChanged: {
        if (!autoPing)
            return

        else if (noDelay) {
            timeout.interval = 1
            timeout.restart()
        }
        else if (text.length > 1 || text == '') {
            timeout.interval = 300
            timeout.restart()
        }
        else {
            timeout.interval = 1500
            timeout.restart()
        }
    }

    Image {
        id: clearicon

        source: parent.text.length > 0 ? clearIcon : idleIcon
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter
        anchors.margins: 4
        fillMode: Image.PreserveAspectFit
        opacity: clearmousearea.containsMouse ? 0.8 : 1.0

        MouseArea {
            id: clearmousearea
            anchors.fill: parent
            hoverEnabled: true
            onClicked: textField.text = ""
        }
    }
}
