import QtQuick 1.1
import QtDesktop 0.1


Rectangle {
    id: explorer

    property string explorerCurrentView: "article"

    color: "#1F1F1F"
    focus: true

    function returnToView() {
        var mod_type = Metadata.source_model
        if (mod_type == "musicView")
            currentView = "lobby"
        else if (mod_type == "queueView")
            currentView = "queue"
    }

    Keys.onPressed: {
        if (event.key == Qt.Key_Escape)
            returnToView()
    }

    onOpacityChanged: {
        if (opacity >= 1.0) {
            forceActiveFocus()
        }
    }

    Item {
        id: trackArt

        anchors.top: parent.top
        anchors.left: parent.left
        anchors.leftMargin: 24
        anchors.topMargin: 24

        width: 300
        height: 300

        Text {
            visible: Metadata.image == ""
            text: "No track art"
            color: Qt.rgba(1,1,1,0.65)
            font.bold: true
            anchors.centerIn: parent

            ListViewButton {
                baseColor: "#454545"
                labelLightenFactor: 1.2

                label: "Add an image"
                anchors.top: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.topMargin: 6

                onClicked: {
                    var path = Utils.display_image_chooser()
                    if (path) {
                        console.log("Save image as track art:", path)
                        Metadata.save_album_art(path)
                    }
                }
            }
        }

        Image {
            source: "../../../data/art/300x300dropshadow.png"

            Image {
                id: actualAlbumArt
                property string albumArtSource: Metadata.image

                x: 11
                y: 8
                width: 300
                height: 300
                source: albumArtSource

                SequentialAnimation {
                    NumberAnimation {
                        target: image
                        property: "opacity"
                        from: 0; to: 1; duration: 300
                        easing.type: Easing.InOutQuad
                        running: true
                    }
                }
            }

            Row {
                anchors.topMargin: 24
                anchors.top: actualAlbumArt.bottom
                anchors.horizontalCenter: actualAlbumArt.horizontalCenter

                spacing: 6

                ListViewButton {
                    label: " Listen "
                    baseColor: "#454545"
                    labelLightenFactor: 1.2

                    onClicked: {
                        Collection.start_current_item()
                    }
                }

                ListViewButton {
                    label: "Reveal file"
                    baseColor: "#454545"
                    labelLightenFactor: 1.2

                    onClicked: {
                        Utils.reveal_location(Metadata.location)
                    }
                }

                ListViewButton {
                    label: "c"
                    baseColor: "#454545"
                    labelLightenFactor: 1.2
                    font.family: "TotallyWired"

                    horizontalPadding: 4

                    onClicked: {
                        Metadata.prev()
                    }
                }

                ListViewButton {
                    label: "d"
                    baseColor: "#454545"
                    labelLightenFactor: 1.2
                    font.family: "TotallyWired"

                    horizontalPadding: 4

                    onClicked: {
                        Metadata.next()
                    }
                }
            }
        }
    }

    Text {
        id: trackTitle
        text: Metadata.title

        color: "#ABAAAA" // abbaaaaaaa!
        style: Text.Raised
        textFormat: Text.RichText

        anchors.top: trackArt.top
        anchors.left: trackArt.right

        anchors.topMargin: 11
        anchors.leftMargin: 56

        Text {
            id: trackDuration
            text: Metadata.duration

            color: "#858484" // abbaaaaaaa!
            style: Text.Raised
            textFormat: Text.RichText

            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.right

            anchors.leftMargin: 6
        }

    }

    Text {
        id: trackSubTitle
        text: Metadata.subtitle

        color: "#ABAAAA" // abbaaaaaaa!
        style: Text.Raised
        textFormat: Text.RichText

        anchors.top: trackTitle.bottom
        anchors.left: trackArt.right

        anchors.topMargin: 6
        anchors.leftMargin: 56
    }

    ListViewButton {
        label: "Metadata Editor"
        anchors.verticalCenter: trackTitle.verticalCenter
        anchors.right: articleScroller.right
        baseColor: "#454545"
    }

    Flickable {
        id: articleScroller

        anchors.top: trackSubTitle.top
        anchors.left: trackArt.right
        anchors.bottom: parent.bottom
        anchors.margins: 56

        contentHeight: articleText.paintedHeight + 100
        width: Math.min(800, explorer.width - x - 112)
        clip: true

        Text {
            id: articleText

            text: Metadata.article
            wrapMode: Text.WordWrap

            width: parent.width - 20
            color: "#ABAAAA" // abbaaaaaaa!
            style: Text.Raised
            textFormat: Text.RichText

            onLinkActivated: {
                Metadata.open_wiki_link(link)
            }

            onTextChanged: SequentialAnimation {

                PropertyAction {
                    target: articleText;
                    property: "opacity";
                    value: 0.3
                }

                NumberAnimation {
                    target: articleText
                    property: "opacity"
                    to: 1; duration: 300
                    easing.type: Easing.InOutQuad
                }
            }

            Image {
                id: wikiLogo
                visible: parent.text != ""
                opacity: 0.2
                source: "../../../data/art/wikipedia-logo.png"
                anchors.top: parent.bottom
                anchors.topMargin: 24

                MouseArea {
                    anchors.fill: parent
                }
            }
        }
    }

    Scrollbar {
        scrollArea: articleScroller

        anchors.right: articleScroller.right
        anchors.top: articleScroller.top
        anchors.bottom: articleScroller.bottom
    }
}
