import QtQuick 1.1
import QtDesktop 0.1


ListView {
    id: list
    objectName: "trackList"

    function saveState() {
        console.log(objectName, "saving state...")
        Utils.settings_set_float_val(titleSep.x / width, "qml", objectName+".titlesepx")
        Utils.settings_set_float_val(albumSep.x / width, "qml", objectName+".albumsepx")
        Utils.settings_set_float_val(artistSep.x / width, "qml", objectName+".artistsepx")
        Utils.settings_set_float_val(durationSep.x / width, "qml", objectName+".durationsepx")
    }

    clip: true
    boundsBehavior: Flickable.StopAtBounds

    property int selection: model.selection
    property int currentStreamIndex: model.current_stream_index
    property alias contextMenu: contextMenu

    property int tracknColWidth: 40
    property int titleColWidth: titleSep.x - tracknColWidth - 3
    property int albumColWidth: albumSep.x - titleSep.x - 3
    property int artistColWidth: artistSep.x - albumSep.x - 3
    property int durationColWidth: durationSep.x - artistSep.x - 3

    Keys.onPressed: {
        if ((event.key == Qt.Key_A) && (event.modifiers & Qt.ControlModifier))
            model.select_all()
    }

    onSelectionChanged: {
        if (selection != currentIndex)
            currentIndex = selection
    }

    onCurrentIndexChanged: {
        if (currentIndex != selection)
            model.update_selection(currentIndex, 0)
    }

    onCurrentStreamIndexChanged: {
        console.log("currentStreamIndex:", currentStreamIndex)
        if (currentStreamIndex != -1)
            positionViewAtIndex(currentStreamIndex, ListView.Visible)
    }

    property bool isCurrentStreamIndexVisible: (
            currentStreamIndex == -1 ||
            currentStreamIndex / count >= visibleArea.yPosition && 
            currentStreamIndex / count <= visibleArea.yPosition + visibleArea.heightRatio)

    HorSeperatorListView {
        id: titleSep
        height: Math.min(list.contentHeight, list.height)
        anchors.top: parent.top
        color: Qt.rgba(0,0,0, 0.05)

        x: parent.width * Utils.settings_get_float_val("qml", list.objectName+".titlesepx", 0.333)
    }

    HorSeperatorListView {
        id: albumSep
        height: Math.min(list.contentHeight, list.height)
        anchors.top: parent.top
        color: Qt.rgba(0,0,0, 0.05)

        x: parent.width * Utils.settings_get_float_val("qml", list.objectName+".albumsepx", 0.666)
    }

    HorSeperatorListView {
        id: artistSep
        height: Math.min(list.contentHeight, list.height)
        anchors.top: parent.top
        color: Qt.rgba(0,0,0, 0.05)

        x: parent.width * Utils.settings_get_float_val("qml", list.objectName+".artistsepx", 0.8)
    }

    HorSeperatorListView {
        id: durationSep
        height: Math.min(list.contentHeight, list.height)
        anchors.top: parent.top
        color: Qt.rgba(0,0,0, 0.05)

        x: parent.width * Utils.settings_get_float_val("qml", list.objectName+".durationsepx", 0.9)
    }

    Rectangle {
        color: list.currentItem != null ? list.currentItem.color : "white"

        width: children[0].width + 8
        height: list.currentItem != null ? list.currentItem.height: 0

        x: list.currentItem != null ? list.currentItem.x + list.currentItem.width - width - 19 : -10000
        y: list.currentItem != null ? list.currentItem.y - list.contentY + (list.currentItem.height - height) / 2 : -10000

        Row {
            x: 4
            anchors.verticalCenter: parent.verticalCenter

            ListViewButton {
                id: enqueueButton
                visible: selection >= 0

                label: (list.currentItem == null ? false : list.currentItem.enqueued) ? "Unqueue" : "Enqueue"
                baseColor: {
                    if (!visible)
                        return activePalette.window
                    else if (list.currentItem.enqueued)
                        return "#90EE90"
                    else
                        return list.currentItem.color
                }

                onClicked: {
                    if (list.currentItem.enqueued) {
                        model.unqueue_selection()
                    }
                    else {
                        model.enqueue_selection()
                    }
                }
            }

            ListViewButton {
                id: dislikeButton
                visible: selection >= 0

                label: visible && list.currentItem.liked != 2 ? "Dislike" : "Disliked"
                baseColor: {
                    if (!visible)
                        return activePalette.window
                    else if (list.currentItem.liked == 2)
                        return "#A52A2A"
                    else
                        return list.currentItem.color
                }

                onClicked: list.model.dislike_selection()
            }

            ListViewButton {
                id: likeButton
                visible: selection >= 0

                label: visible && list.currentItem.liked != 1 ? "Like" : "Liked"
                baseColor: {
                    if (!visible)
                        return activePalette.window
                    else if (list.currentItem.liked == 1)
                        return "#FF879C"
                    else
                        return list.currentItem.color
                }

                onClicked: list.model.like_selection()
            }

            ListViewButton {
                id: infoButton
                visible: selection >= 0

                height: likeButton.height

                label: "b"
                font.family: "TotallyWired"
                font.pixelSize: em
                baseColor: list.currentItem != null ? list.currentItem.color : "black" 

                onClicked: editorLoader.showEditor(list.model)
            }
        }
    }

    ContextMenu {
        id: contextMenu

        MenuItem {
            text: "Search by Artist"

            onTriggered: {
                searchentry.noDelay = true
                searchentry.text = "artist(%1)".arg(list.currentItem.artist)
            }
        }
        MenuItem {
            text: "Search by Album"

            onTriggered: {
                searchentry.noDelay = true
                searchentry.text = "album(%1)".arg(list.currentItem.album)
            }
        }
        MenuItem {
            text: "Track Properties..."

            onTriggered: {
                editorLoader.showEditor(list.model)
            }
        }
    }

    Scrollbar {
        anchors.right: list.right
        anchors.top: list.top
        anchors.bottom: list.bottom
        anchors.margins: 3
        scrollArea: list
    }
}
