import QtQuick 1.1


Rectangle {
    id: row

    property alias mouseArea: area
    property bool isCurrentStream: (list.currentStreamIndex == index)
    property color text_color: isCurrentStream | selected ? Qt.lighter(row.color, 1.8) : activePalette.text
    property color textstyle_color: isCurrentStream | selected ? Qt.darker(row.color, 1.8) : Qt.lighter(row.color, 1.3)

    property string trackn: _track_n
    property string title: _title
    property string album: _album
    property string artist: _artist
    property string duration: _duration
    property string tags: _tags
    property int liked: _liked
    property bool enqueued: _enqueued
    property bool selected: _selected

    property int _pointSize: 9

    height: 2.5 * em
    x: 0
    width: parent.width

    color: {
        if (selected) {
            if (isCurrentStream) {
                return "#ED303C"
            }
            else {
                return "#FF9C5B"
            }
        }
        else if (isCurrentStream) {
            return "#F5634A"
        }
        else {
            return "#E0DAD5"
        }
    }

    MouseArea {
        id: area

        anchors.fill: parent
        acceptedButtons: Qt.LeftButton | Qt.RightButton

        function updateSelection(mouse, index) {
            list.model.update_selection(index, mouse.modifiers)
        }

        onClicked: {
            list.forceActiveFocus()
            if (mouse.button == Qt.LeftButton) {
                updateSelection(mouse, index)
            }
            else if (mouse.button == Qt.RightButton) {
                if (!list.model.is_selected(index))
                    updateSelection(mouse, index)

                var point = mapToItem(toplevel, mouseX, mouseY)
                console.log(mouseX, mouseY)
                list.contextMenu.showPopup(point.x, point.y)
            }
        }

        onDoubleClicked: {
            if (mouse.button == Qt.LeftButton) {
                list.forceActiveFocus()
                list.model.start_current_item()
            }
        }
    }
}
