import QtQuick 1.1
import QtDesktop 0.1

Flickable {

    id: scrollArea
    clip: true
    boundsBehavior: Flickable.StopAtBounds

    Item {
        id: editor

        width: Math.min(800, parent.width)
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.bottom: parent.bottom
        anchors.margins: 36

        focus: true

        Keys.onPressed: {
            if (event.key == Qt.Key_Escape) {}
        }

        onOpacityChanged: {
            if (opacity >= 1.0) {
                forceActiveFocus()
            }
        }

        TextLabel {
            id: title

            anchors.top: parent.top
            anchors.left: parent.left
            anchors.right: parent.right

            text: '<font size="20" color="#919090"><b>Audio CD information lookup</b><br></font><br>Manually edit track information or use the Musicbrainz service to discover the release information.'
            style: Text.Raised
            styleColor: "#FFFDFD"
        }

        Column {
            id: mbSearchRow
            anchors.top: title.bottom
            anchors.left: parent.left
            anchors.right: parent.right
            anchors.topMargin: 36

            spacing: 12

            TextField {
                id: mbArtistSearch
                placeholderText: "Artist"
                width: 600
                text: Metadata.editor.artist
            }

            TextField {
                id: mbAlbumSearch
                placeholderText: "Album"
                width: 600
                text: Metadata.editor.album
            }

            Row {
                spacing: 6

                TextField {
                    id: mbGenreSearch
                    placeholderText: "Genre"

                    Component.onCompleted: {
                        width = 600 - mbDateSearch.width - parent.spacing
                   }
                }

                TextField {
                    id: mbDateSearch
                    width: 100
                    placeholderText: "Date"
                    text: Metadata.editor.date
                }
            }

            Row {
                property int discCount: Metadata.editor.disc_count

                opacity: discCount > 1
                spacing: 6

                TextLabel {
                    anchors.verticalCenter: parent.verticalCenter
                    text: "This is a <i>DualDisc</i> release.  Which disc do you currently have loaded?"
                }

                ComboBox {
                    model: ListModel {
                        id: menuItems

                        ListElement { text: "Disc 1" }
                        ListElement { text: "Disc 2" }
                    }

                    id: mbDiscNSearch
                    width: 80

                    onSelectedIndexChanged: {
                        Metadata.editor.set_disc(selectedIndex)
                    }
                }
            }

            Button {
                text: "Search MusicBrainz"
                x: mbAlbumSearch.x
                height: mbArtistSearch.height

                onClicked: {
                    Metadata.editor.release_lookup(
                        mbAlbumSearch.text, mbArtistSearch.text,
                        mbDiscNSearch.selectedIndex)
                }
            }
        }

        Column {
            id: trkList

            anchors.top: mbSearchRow.bottom
            anchors.left: mbSearchRow.left
            anchors.topMargin: 36

            spacing: 2

            Repeater {
                id: repeater
                model: Metadata.editor

                onCountChanged: {
                    trkList.height = count * (mbArtistSearch + trkList.spacing)
                }

                Row {
                    spacing: 4

                    TextLabel {
                        anchors.verticalCenter: parent.verticalCenter
                        width: 25

                        text: (index + 1) + "."
                    }

                    TextLabel {
                        text: Metadata.editor.getstr(index, "_tN")
                        width: 600
                    }
                }
            }
        }

        Button {
            id: saveButton

            property bool isSaved: Metadata.editor.is_saved

            anchors.top: trkList.bottom
            anchors.left: mbSearchRow.left
            anchors.topMargin: 24

            text: "Save changes"
            height: opacity > 0 ? mbArtistSearch.height : 0
            opacity: Metadata.editor.result_ready ? 1 : 0

            Behavior on opacity { PropertyAnimation {duration: 500} }

            onClicked: {
                if (!isSaved)
                    Metadata.editor.save_changes()
            }

            onIsSavedChanged: {
                if (isSaved) {
                    text = "Changes saved"
                    opacity = 0.5
                }
                else {
                    text = "Save changes"
                    opacity = 1.0
                }
            }

            onYChanged: {
                scrollArea.contentHeight = y + height + 96
            }
        }
    }
}
