import QtQuick 1.1
import QtDesktop 0.1

import "./Widgets" as Widgets


Widgets.TopLevelWindow {
    id: toplevel

    property int em: Utils.em
    property string currentView: "lobby"

    Widgets.TextEntryField {
        id: searchentry
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.topMargin: 6
        anchors.leftMargin: 6
        minWidth: parent.width * 0.25

        onUTextChanged: {
            currentView = "lobby"
            editorLoader.closeEditor()
            Collection.new_query_from_string(text)
        }
    }

    Row {
        spacing: 10
        anchors.right: parent.right
        anchors.verticalCenter: searchentry.verticalCenter
        anchors.margins: 6

        Widgets.ViewSelector {
            text: "Music"
            viewId: "lobby"
        }
        Widgets.ViewSelector {
            text: Queue.count > 0 ? "%1 Queued".arg(Queue.count) : "Queue"
            viewId: "queue"
        }
        Widgets.ViewSelector {
            text: "Audio CD"
            viewId: "cdda"
        }
        Widgets.ViewSelector {
            text: "Radio"
            viewId: "radio"
        }
        Widgets.ViewSelector {
            text: "Sources"
            viewId: "folder-manager"
        }
    }

    Widgets.MusicLibraryView {
        id: library
        opacity: currentView != "lobby" | editorLoader.whoCalled == "lobby" ? 0 : 1
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Loader {
        id: queueview
        source: currentView == "queue" ? "Widgets/QueueView.qml" : ""
        opacity: currentView != "queue" | editorLoader.whoCalled == "queue" ? 0 : 1
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Loader {
        id: cddaview
        // lazy load but do not unload view
        source: {
            if (currentView == "cdda") {
                if (source == "")
                    source = "Widgets/CddaView.qml"
            }
            else
                ""
        }
        opacity: currentView != "cdda" | editorLoader.whoCalled == "cdda" ? 0 : 1
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Loader {
        source: currentView == "radio" ? "Widgets/RadioStationView.qml" : ""
        opacity: currentView == "radio" ? 1 : 0
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Loader {
        source: currentView == "folder-manager" ? "Widgets/FolderManagerView.qml" : ""
        opacity: currentView == "folder-manager" ? 1 : 0
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Loader {
        id: editorLoader

        function showEditor(model) {
            whoCalled = currentView
            source = "Widgets/TrackEditor.qml"
            item.set_model(model)
            console.log(model)
        }

        function closeEditor() {
            whoCalled = ""
            source = ""
        }

        property string whoCalled: ""

        opacity: currentView == whoCalled ? 1 : 0
        anchors.topMargin: 6
        anchors.top: searchentry.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: appPageControlArea.top
        Behavior on opacity { PropertyAnimation {duration: 150} }
    }

    Connections {
        target: editorLoader.item
        onClose: editorLoader.closeEditor()
    }

    Image {
        source: "../../data/art/dropshadow-north.png"
        width: parent.width
        anchors.top: library.top
        anchors.left: parent.left
    }

    Image {
        source: "../../data/art/dropshadow-south.png"
        width: parent.width
        anchors.bottom: appPageControlArea.top
        anchors.left: parent.left
    }

    Widgets.Pager {
        id: appPageControlArea
    }
}
