import os
import os.path
#~ import json
#~ import urllib
#~ import urllib2
import xapian
import hashlib
import pickle

from gi.repository import GLib

from totallywired.db.collectors.enums import Extensions
from totallywired.db.collectors.enums import DbEnums
from totallywired.db.enums import TWXDB_BASEPATH

from paths import (
    recursive_find_by_ext,
    source2collection,
    collection2source,
    is_cdda_path,
    is_cdda_gvfs)

_alldocuments = "Xapian::Query(<alldocuments>)"
def is_alldocuments_query(q):
    return str(q) == _alldocuments

def purge_all_terms(doc):
    for t in doc.termlist():
        tt = t.term
        if (tt.startswith(DbEnums.T_TRACKNUM) or
            tt.startswith(DbEnums.T_DATE) or
            tt.startswith(DbEnums.T_ARTIST) or
            tt.startswith(DbEnums.T_ALBUM) or
            tt.startswith(DbEnums.T_TAGS) or
            tt.startswith(DbEnums.T_TITLE)):
            doc.remove_term(t.term)
    return

def get_doccount(index):
    db = xapian.Database(index)
    return db.get_doccount()

def mklasttime(index, cur=None):
    outpath = os.path.join(index, 'lasttime')
    outfile = open(outpath, 'w')
    if cur is None:
        cur = recursive_find_by_ext(collection2source(index))
    pickle.dump(cur, outfile)
    outfile.close()
    return outpath

def difflasttime(index, cur=None):
    p = os.path.join(index, 'lasttime')
    if not os.path.exists(p):
        tmp = open(p, 'w')
        pickle.dump([], tmp)
        tmp.close()

    infile = open(p, 'r')
    if cur is None:
        cur = set(recursive_find_by_ext(collection2source(index)))
    old = set(pickle.load(infile))
    return old.symmetric_difference(cur), cur

def get_all_sources(root=TWXDB_BASEPATH):
    return (collection2source(d) for d in os.listdir(root) 
            if os.path.isdir(os.path.join(root, d)) and
            not d.endswith(".indexing"))

def get_live_sources(root=TWXDB_BASEPATH):
    return [s for s in get_all_sources(root) if os.path.isdir(s)]

def get_all_indexes(root=TWXDB_BASEPATH):
    return [p for p in [os.path.join(root, d) for d in os.listdir(root)] if os.path.isdir(p)]

def get_live_indexes(root=TWXDB_BASEPATH):
    return [d for d in get_all_indexes(root) if os.path.isdir(collection2source(d))]

def get_collated_database(collections, root=TWXDB_BASEPATH):
    db = False
    for c in collections:
        if not c.xpath or not c.live or c.hidden:
            continue
        if not db:
            try:
                db = xapian.Database(c.xpath)
            except xapian.DatabaseOpeningError:
                continue
        elif os.path.exists(c.xpath):
            try:
                _db = xapian.Database(c.xpath)
            except xapian.DatabaseOpeningError:
                continue
            db.add_database(_db)
        else:
            print("XPath does not yet exist! (%s)" % c.xpath)
    return db

def get_source_for_uri(uri, root):
    path = GLib.filename_from_uri(uri, "")
    if uri.startswith("cdda:") or is_cdda_path(path):
        return os.path.join(os.path.expanduser("~"), ".gvfs/cdda mount on sr0")

    live_sources = get_live_sources(root)

    for src in live_sources:
        if path.startswith(src):
            return src
    return ''

def get_writable_twxdb_for_uri(uri, root=TWXDB_BASEPATH):
    the_src = get_source_for_uri(uri, root)

    if the_src:
        index = source2collection(the_src)
        db = get_twxdb_by_path(os.path.join(root, index))
    else:
        db = the_src = None
    return db, the_src

def get_twxdb_by_path(path):
    return xapian.WritableDatabase(path, xapian.DB_OPEN)

def get_twxdb_for_uri(uri, root=TWXDB_BASEPATH):
    the_src = get_source_for_uri(uri, root)

    if the_src:
        index = source2collection(the_src)
        db = xapian.Database(os.path.join(root, index))
    else:
        db = the_src = None
    return db, the_src

def get_term_generator(db):
    tg = xapian.TermGenerator()
    tg.set_database(db)
    tg.set_flags(xapian.TermGenerator.FLAG_SPELLING)
    return tg

def get_writable_doc_for_uri(uri, root=TWXDB_BASEPATH):
    # get a writable database and the doc
    db, _ = get_writable_twxdb_for_uri(uri, root)
    pl = db.postlist(get_qterm(uri))
    try:
        plitem = next(pl)
    except StopIteration:
        raise KeyError("No document with QTerm: %s" % get_qterm(uri))
        return db, None, -1
    docid = plitem.docid
    return db, db.get_document(docid), docid

def get_doc_from_uri(db, uri):
    pl = db.postlist(get_qterm(uri))
    try:
        plitem = next(pl)
    except StopIteration:
        print("No document with QTerm: %s" % get_qterm(uri))
        return -1
    docid = plitem.docid
    return db.get_document(docid), docid

def get_doc_from_qterm(db, qterm):
    pl = db.postlist(qterm)
    try:
        plitem = next(pl)
    except StopIteration:
        print("No document with QTerm: %s" % qterm)
        return False, 0
    return db.get_document(plitem.docid), plitem.docid

def get_docids_from_group_qterm(db, qterm, maxlen=50):
    pl = db.postlist(qterm)
    docs = []
    i = 0
    try:
        while i < maxlen:
            plitem = next(pl)
            docs.append(plitem.docid)
            i += 1
    except StopIteration:
        pass
    return docs

def qterm_in_db(db, qterm):
    pl = db.postlist(qterm)
    try:
        next(pl)
    except StopIteration:
        return False
    return True

#~ def create_document_for_file(db, collector, f, term_generator=None):
    #~ if not os.path.splitext(f)[1] in Extensions.VALID:
        #~ return
    #~ #doc, tg, f, data, kmap, liked=[], disliked=[]
    #~ 
    #~ collector.index_document(
        #~ db, term_generator or get_term_generator(db), f,
        #~ )
    #~ return

def get_qterm(uri):
    if is_cdda_gvfs(uri):
        trackn = os.path.split(uri)[-1]
        uri = "cdda"+trackn
    h = hashlib.md5()
    h.update(uri.lower())
    return h.hexdigest()

def get_prefixed_qterm(prefix, str_):
    if not isinstance(str_, str):
        str_ = str_.encode("utf-8")
    h = hashlib.md5()
    h.update(str_)
    return prefix + h.hexdigest()

def get_artist_qterm(s):
    return get_prefixed_qterm(DbEnums.T_ARTIST, s)

def get_album_qterm(s):
    return get_prefixed_qterm(DbEnums.T_ALBUM, s)

def get_writable_twxdbs_for_uris(uris):
    # process uris to determine which dbs we will need, and return 
    # a list of uris for each dbs for convienient handling
    dbs = {}
    for uri in uris:
        src = get_source_for_uri(uri, TWXDB_BASEPATH)
        if not src in dbs:
            db_path = source2collection(src)
            dbs[src] = (get_twxdb_by_path(db_path), [uri,])
        else:
            dbs[src][1].append(uri)
    return dbs


#~ 
#~ def google_it(q, site):
    #~ if not q:
        #~ return False
#~ 
    #~ qstr = '%s site:%s' % (q, site)
    #~ query = urllib.urlencode({'q': qstr})
#~ 
    #~ url = 'https://www.googleapis.com/customsearch/v1?key=%s&cx=%s&num=5&%s' % (
        #~ "AIzaSyAUq0qerCBEjygk5IaPNXQN0IwZ0RQUFvI",
        #~ "002981956753261166911:z9u04a2irja",
        #~ query)
#~ 
    #~ try:
        #~ response = urllib2.urlopen(url)
    #~ except IOError as e:
        #~ print(e)
        #~ return False
#~ 
    #~ results = response.read()
    #~ results = json.loads(results)
#~ 
    #~ try:
        #~ if int(results['searchInformation']['totalResults']) == 0:
            #~ return False
    #~ except KeyError as e:
        #~ print(e, results)
        #~ return False
#~ 
    #~ res = results['items']
    #~ n = len(results['items'])
    #~ i = 0
    #~ while ("File:" in res[i]['formattedUrl'] or
           #~ "File_talk:" in res[i]['formattedUrl']):
        #~ i += 1
        #~ if i == n:
            #~ return False
#~ 
    #~ data = results['items'][i]['formattedUrl']
    #~ return data
