import os
import glob

from os.path import basename, splitext


def get_theme_name():
    from subprocess import Popen, PIPE
    # a bit of a hack...
    p = Popen(["gsettings", "get", "org.gnome.desktop.interface", "icon-theme"], stdout=PIPE)
    theme = p.communicate()[0].strip().strip("'")
    return theme


class IconFetcher(object):

    ICON_SEARCH_PATH = "/usr/share/icons/%s"
    ADDITIONAL_SEARCH_PATHS = []

    def __init__(self, section):
        self.theme_name = ""
        #~ self.icons32 = {}
        self.icons64 = {}
        self.section = section
        self.set_icon_theme(get_theme_name())
        return

    def __getitem__(self, k):
        return self.get_iconpath32(k)

    def _get_inherited_theme(self, path):
        theme_index = os.path.join(path, "index.theme")
        if not os.path.exists(theme_index):
            return []
        with open(theme_index) as f:
            for ln in f.readlines():
                if ln.startswith("Inherits="):
                    inherits = ln.split("=")[1].strip()
                    return [self.ICON_SEARCH_PATH % i for i in inherits.split(",")]
        return []

    def _cache_icons(self, icons, path, search_term):
        if not os.path.exists(path):
            return self._get_inherited_theme(path)
        for f in glob.glob(os.path.join(path, search_term)):
            k = splitext(basename(f))[0]
            if k not in icons:
                icons[k] = f
        return self._get_inherited_theme(path)

    def _rebuild_cache(self):
        path = self.ICON_SEARCH_PATH % self.theme_name
        for icons, search_term in ((self.icons64, "%s/64/*.png" % self.section),):
            inherits = self._cache_icons(icons, path, search_term)
            while inherits:
                i = []
                for path in inherits:
                    i.extend(self._cache_icons(icons, path, search_term))
                inherits = i
            for path in self.ADDITIONAL_SEARCH_PATHS:
                self._cache_icons(icons, path, "*.png")
        return

    def _underscored_path(self, name):
        path = name.replace("_", os.sep)
        if os.path.exists(path):
            return path
        return ""

    def set_icon_theme(self, theme_name):
        self.theme_name = theme_name
        self._rebuild_cache()
        return

    #~ def get_iconpath32(self, name):
        #~ if name.startswith("_"):
            #~ return self._underscored_path(name)
        #~ elif name in self.icons32:
            #~ return self.icons32[name]
        #~ return ""

    def get_iconpath64(self, name):
        if name.startswith("_"):
            return self._underscored_path(name)
        elif name in self.icons64:
            return self.icons64[name]
        return ""
