import os
import json
import string
import codecs
import urllib
import urllib2

from lxml import etree
from musicbrainzngstw import musicbrainz as mb

AUDIOSCROBBLER_API_KEY = "76e1971c91586b3e377adaf7a79db0e6"
AUDIOSCROBBLER_API = "http://ws.audioscrobbler.com/2.0/?"

from totallywired.utils.discid import (
    Disc,
    DiscError)

from totallywired.utils.db import get_artist_qterm
from totallywired.utils.caching import Caches


mb.set_useragent(
    "TotallyWired", "0.1",
    "Matthew McGowan <matthew.joseph.mcgowan@gmail.com>")


def _webget(url, timeout=10):
    try:
        data = urllib2.urlopen(url, timeout=timeout)
    except urllib2.URLError:
        return False
    except Exception as e:
        print("Somthing bad happend: %s" % e)
        return False
    return data

def get_cdda_discid():
    try:
        # Read the disc in the default disc drive. If necessary, you can pass
        # the 'deviceName' parameter to select a different drive.
        disc = Disc()
    except DiscError as e:
        print("DiscID calculation failed:", str(e))
        return False
    return disc.id

def get_mbid_from_discid(discid):
    try:
        releases = mb.get_releases_by_discid(discid)
    except Exception as e:
        print('Could not find a releases for disc:%s!' % discid)
        print(e)
        return False
    try:
        mbid = releases['disc']['release-list'][0]['id']
    except Exception as e:
        print('Could not find mbid!')
        print(e)
        return False
    return mbid

def get_artwork(mbid="", artist="", album=""):
    if not artist and not album:
        return ""
    url = AUDIOSCROBBLER_API + "api_key=%s&method=album.getinfo&mbid=%s&" % (
        AUDIOSCROBBLER_API_KEY, mbid)
    data = _webget(url)
    if data:
        root = etree.XML(data.read())
        image_finder = etree.XPath("//image")
        images = image_finder(root)
        for im in images:
            if ("size" in im.attrib and
                im.attrib["size"] == "large"):
                print(artist, album, "Large image at:", im.text)
                return im.text
    return ""

def get_cdda_artwork_easily():
    did = get_cdda_discid()
    if not did:
        return ""
    mbid = get_mbid_from_discid(did)
    if not mbid:
        return ""
    return get_artwork(mbid)

# example query
# query = '"%s" AND artist:"%s"' % (album, artist)
def get_mbid_from_mbquery(query):
    try:
        if hasattr(mb, "release_search"):
            res = mb.release_search(query=query, limit=1)
        elif hasattr(mb, "search_releases"):
            res = mb.search_releases(query=query, limit=1)
    except Exception as e:
        print("Could not lookup release")
        print(e)
        return False
    if res['release-list']:
        mbid = res['release-list'][0]['id']
        return mbid
    return False

def query_artwork(album, artist):
    if "[" in album:
        album = album[:album.find("[")].strip()
    elif "(" in album:
        album = album[:album.find("(")].strip()
    query = '"%s" AND artist:"%s"' % (album, artist)
    mbid = get_mbid_from_mbquery(query)
    if not mbid:
        return False
    return get_artwork(mbid)


_htmlstyle = "<html><head><style type='text/css'>a:link {text-decoration:none;color:#FF3333;}</style></head>%s</html>"
_link = '<a href="%s">%s</a>'
class Similar(object):
    
    def __init__(self, _dict):
        self._dict = _dict
        return

    def __repr__(self):
        return self.name

    @property
    def name(self):
        return self._dict["name"]

    @property
    def artist(self):
        try:
            return self._dict["artist"]["name"]
        except:
            pass
        return self.name

    @property
    def namelink(self):
        return _htmlstyle % _link % (self._dict["url"], self._dict["name"])

    @property
    def term(self):
        return self._dict["name"]

    @property
    def termfreq(self):
        return 0

    @property
    def image(self):
        return self._dict["image"][1]["#text"]


def get_similar_artists(mbid="", artist="", limit=4):
    limit = limit or 1
    if mbid:
        req = "api_key=%s&method=artist.getsimilar&mbid=%s&limit=%s&format=json" % (
            AUDIOSCROBBLER_API_KEY, mbid, limit)
    elif artist:
        req = "api_key=%s&method=artist.getsimilar&artist=%s&autocorrect=1&limit=%s&format=json" % (
            AUDIOSCROBBLER_API_KEY, urllib.quote(artist), limit)
    else:
        raise(ValueError(repr(mbid), repr(artist)))

    url = AUDIOSCROBBLER_API + req
    data = _webget(url)
    if data:
        try:
            similar = json.loads(data.read())["similarartists"]["artist"]
        except:
            return []
        if similar:
            return [Similar(artist) for artist in similar]
    return []

def get_similar_tracks(mbid="", artist="", track="", limit=6):
    if mbid:
        req = "api_key=%s&method=track.getSimilar&mbid=%s&limit=%s&format=json" % (
            AUDIOSCROBBLER_API_KEY, mbid, limit)
    elif artist and track:
        req = "api_key=%s&method=track.getSimilar&artist=%s&track=%s&limit=%s&autocorrect=1&format=json" % (
            AUDIOSCROBBLER_API_KEY, urllib.quote(artist), urllib.quote(track), limit)
    else:
        raise(ValueError("kwargs must consist of an mbid or artist name AND track name, got: ", repr(mbid), repr(artist), repr(track)))
    url = AUDIOSCROBBLER_API + req
    data = _webget(url)
    if data:
        try:
            similar = json.loads(data.read())["similartracks"]["track"]
        except:
            return []
        if similar:
            return [Similar(trk) for trk in similar]
    return []

def _readfile(_file):
    try:
        with codecs.open(_file, "r", "utf-8") as f:
            return f.read()
    except Exception as e:
        print("Error opening file %s. %s" % (_file, e))
    return ""

def get_artist_biography(mbid="", artist="", lang="en"):
    path = os.path.join(Caches.BIOS, get_artist_qterm(artist))
    if os.path.exists(path):
        return _readfile(path)
    if mbid:
        req = "api_key=%s&method=artist.getInfo&mbid=%s&lang=%s&format=json" % (
            AUDIOSCROBBLER_API_KEY, mbid, lang)
    elif artist:
        req = "api_key=%s&method=artist.getInfo&artist=%s&autocorrect=1&lang=%s&format=json" % (
            AUDIOSCROBBLER_API_KEY, urllib.quote(artist), lang)
    else:
        raise(ValueError(repr(mbid), repr(artist)))
    url = AUDIOSCROBBLER_API + req
    data = _webget(url)
    if data:
        try:
            raw = json.loads(data.read())
            bio = raw["artist"]["bio"]["summary"]
        except:
            return "", raw["artist"]["url"]
        with open(path, "w") as f:
            f.write(bio.encode("utf-8", "ignore"))
        return bio
    return "", ""
