import os.path
import subprocess
import unicodedata

from PyQt4.QtGui import QCursor
from PyQt4.QtCore import (
    Qt,
    QObject,
    pyqtSlot,
    pyqtProperty,
    pyqtSignal)


class MiscUtils(QObject):

    _styleChanged = pyqtSignal()

    def __init__(self, app):
        QObject.__init__(self)
        self.app = app
        self._parents = {}
        return

    @pyqtProperty(int, notify=_styleChanged)
    def em(self):
        return 14

    @pyqtSlot(str, str, int, result=int)
    def settings_get_int_val(self, group, key, default):
        settings = self.app.settings
        settings.beginGroup(str(group))
        v = settings.value(key, default).toInt()[0]
        settings.endGroup()
        return v

    @pyqtSlot(str, str, float, result=float)
    def settings_get_float_val(self, group, key, default):
        settings = self.app.settings
        settings.beginGroup(str(group))
        v = settings.value(key, default).toFloat()[0]
        settings.endGroup()
        return v

    @pyqtSlot(float, str, str)
    def settings_set_float_val(self, v, group, key):
        print(key, v)
        settings = self.app.settings
        # XXX: cheat here, this is called on_close within the store
        # state routine, in which the group is already set for us...
        #~ settings.beginGroup(str(group))
        v = settings.setValue(key, v)
        #~ settings.endGroup()
        return v

    @pyqtSlot(int, str, str)
    def settings_set_int_val(self, v, group, key):
        print(key, v)
        settings = self.app.settings
        # XXX: cheat here, this is called on_close within the store
        # state routine, in which the group is already set for us...
        #~ settings.beginGroup(str(group))
        v = settings.setValue(key, v)
        #~ settings.endGroup()
        return v

    @pyqtSlot(str, result=str)
    def settings_get_string_val(self, key):
        return self.app.settings.value(key)

    @pyqtSlot(result=int)
    def get_toplevel_width(self):
        settings = self.app.settings
        settings.beginGroup("mainwindow")
        w = self.app.settings.value('width').toInt()[0]
        settings.endGroup()
        desktop = self.app.app.desktop()
        avail_width = desktop.availableGeometry().width()
        if w == 0:
            return int(avail_width * 0.7)
        return min(avail_width - 100, w)

    @pyqtSlot(result=int)
    def get_toplevel_height(self):
        settings = self.app.settings
        settings.beginGroup("mainwindow")
        h = settings.value('height').toInt()[0]
        settings.endGroup()
        desktop = self.app.app.desktop()
        avail_height = desktop.availableGeometry().height()
        if h == 0:
            return int(avail_height * 0.7)
        return min(avail_height-100, h)

    @pyqtSlot(str)
    def set_cursor(self, cursor):
        shape = ""
        if cursor == "hsplit":
            shape = QCursor(Qt.SplitHCursor)
        elif cursor == "vsplit":
            shape = QCursor(Qt.SplitVCursor)
        else:
            shape = QCursor(Qt.ArrowCursor)
        self.app.view.setCursor(shape)
        return

    @pyqtSlot(str)
    def reveal_location(self, location):
        subprocess.check_call(['xdg-open', "%s" % str(location)])
        return


class StdoutColors:
    BOLD = '\033[1m'
    HEADER = '\033[95m'
    OKBLUE = '\033[94m'
    OKGREEN = '\033[92m'
    WARNING = '\033[93m'
    FAIL = '\033[91m'
    ENDC = '\033[0m'


def tail(path_or_uri):
    return os.path.split(path_or_uri)[-1]

def ellipsis(str_, maxlen=80):
    str_len = len(str_)
    slice_point = str_len - maxlen - 3
    return ('..' + str_[slice_point:]) if str_len > maxlen else str_


import re
class SubMany(object):

  def __init__(self, replacements_dict):
    self.replacements = replacements_dict
    self.locator = re.compile('|'.join(re.escape(s) for s in replacements_dict))

  def _replace(self, mo):
    return self.replacements[mo.group()]

  def sub(self, s):
    return self.locator.sub(self._replace, s).replace('  ', ' ').replace('   ', ' ')


def parse_date_as_year_only(date_unicode):
    d = unicode(date_unicode).strip()
    if d.isnumeric():
        if d.startswith('0') and not int(d):
            return ''
        return d
    elif d.find('-') > -1:
        return str(d.split('-')[0])
    return d

def remove_diacritical_marks(in_unicode):
    nrm = unicodedata.normalize('NFKD', unicode(in_unicode))
    return "".join([c for c in nrm if not unicodedata.combining(c)])

_MS = "%d:%02d"
_HMS = "%d:%02d:%02d"
def get_nice_hms(secs):
    m, s = divmod(secs, 60)
    h, m = divmod(m, 60)
    if h > 0:
        return _HMS % (h, m, s)
    return _MS % (m, s)
