import os
import os.path
import glob
import hashlib

from totallywired.utils.discid import Disc
from totallywired.utils.caching import Caches
from totallywired.db.collectors.enums import Extensions


def collection2source(d):
    d = os.path.split(d)[-1]
    if d.rfind(':') > 0:
        return d.replace('.', '/').replace('__dot__', '.')
    return os.sep + d.replace('.', '/').replace('__dot__', '.')

parser = lambda s: s.strip('/').replace("/.", ".__dot__").replace('/', '.')
def source2collection(source):
    if is_cdda_gvfs(source):
        if not os.path.exists(get_cdda_gvfs()):
            return ""
        discid = Disc().id
        h = hashlib.md5()
        h.update(discid)
        return os.path.join(Caches.XAPIAN, "cdda", h.hexdigest())
    return os.path.join(Caches.XAPIAN, parser(source))

_cdda_gvfs = ""
def get_cdda_gvfs(candidate=0):
    global _cdda_gvfs
    if _cdda_gvfs:
        return _cdda_gvfs

    # 12.04 and earlier
    gvfs = os.path.expanduser("~/.gvfs")
    candidates = glob.glob(os.path.join(gvfs, "cdda*"))
    if not candidates:
        # for 12.10
        import getpass
        gvfs = "/run/user/%s/gvfs/" % getpass.getuser()
        print(gvfs)
        candidates = glob.glob(os.path.join(gvfs, "cdda*"))
    if not candidates:
        return ""
    _cdda_gvfs = candidates[candidate]
    return _cdda_gvfs

def is_cdda_path(path):
    return is_cdda_gvfs(path)

def is_cdda_gvfs(path):
    return path.find("gvfs/cdda") > 0

def is_trash_path(path):
    return path.find(".Trash") > 0

def recursive_find_by_ext(source, valid_extns=Extensions.VALID):
    audiofiles = []

    def visitor(arg, dirname, names):
        for f in names:
            if f.startswith('.'):   # ignore hidden files
                continue
            if os.path.splitext(f)[1] in valid_extns:
                audiofiles.append(os.path.join(dirname, f))
        return

    os.path.walk(source, visitor, None)
    return audiofiles
